import 'package:flutter/material.dart';
import 'package:base_repository/base_repository.dart';
import 'package:xiaoxiong_repository/entity/product_details_entity.dart';
import 'package:xiaoxiong_repository/entity/product_item_entity.dart';
import 'package:xiaoxiong_repository/entity/turn_chain_entity.dart';

import '../price_repository.dart';

class PriceRepositoryImpl extends PriceRepository {
  PriceRepositoryImpl.get();
  static final PriceRepositoryImpl _instance = PriceRepositoryImpl.get();
  factory PriceRepositoryImpl() {
    return _instance;
  }

  ///
  /// 获取好价商品列表
  /// [page]                  当前页数
  /// [pagesize]              每页显示的数量
  /// [keywords]              搜索的关键词
  /// [filters]               过滤条件
  ///
  @override
  Future<DSResponseList<ProductItemEntity>> qryProductList(
      {int page = 1,
      int pagesize = 10,
      String categoryId,
      String excludeId,
      String keywords,
      List<dynamic> filters}) async {
    Map<String, dynamic> query = {
      'page': page,
      'pagesize': pagesize,
    };
    if (keywords != null && keywords.isNotEmpty) {
      query['keywords'] = keywords;
    }
    if (filters != null && filters.length > 0) {
      query['filters'] = filters;
    }
    if (categoryId != null && categoryId.isNotEmpty) {
      query['category_id'] = categoryId;
    }
    if (excludeId != null && excludeId.isNotEmpty) {
      query['exclude_id'] = excludeId;
    }
    dynamic result = await DSDioUtil.getInstance()
        .get('/itemSelling.getList', queryParameters: query);
    return DSResponseList<ProductItemEntity>.fromJson(
        result, ProductItemEntity.fromJson);
  }

  ///
  /// 获取商品详情
  /// [id]                  商品详情Id
  ///
  @override
  Future<DSResponseObject<ProductDetailsEntity>> qryProductDetails(
      {String id}) async {
    dynamic result = await DSDioUtil.getInstance()
        .get('itemSelling.detail', queryParameters: {'id': id});
    return DSResponseObject.fromJson(result, ProductDetailsEntity.fromJson);
  }

  ///
  /// 举报
  /// [id]                  举报的商品Id
  /// [report_type]         举报的商品类型
  ///
  @override
  Future<DSResponseBool> report({String id, String reportType}) async {
    dynamic result = await DSDioUtil.getInstance().post('itemSelling.report',
        data: {'id': id, 'report_type': reportType});
    return DSResponseBool.fromJson(result);
  }

  ///
  /// 用户点赞
  ///
  ///
  @override
  Future<DSResponseBool> userLike(
      {@required String markId,
      String type = '2',
      String status = '1',
      String platform = '20'}) async {
    dynamic result = await DSDioUtil.getInstance().post('itemLike.userLike',
        data: {
          'mark_id': markId,
          'type': type,
          'status': status,
          'platform': platform
        });
    return DSResponseBool.fromJson(result);
  }

  @override
  Future<DSResponseBool> userCollect(
      {String itemId,
      String type = '2',
      String platform = '20',
      String status = '1'}) async {
    dynamic result = await DSDioUtil.getInstance().post('collect.doCollect',
        data: {
          'item_id': itemId,
          'type': type,
          'status': status,
          'platform': platform
        });
    return DSResponseBool.fromJson(result);
  }

  ///
  /// 通过商品Id进行转链
  /// [itemId]                  商品id
  /// [platform]                平台，1淘宝 2京东 3拼多多 4唯品会  7、苏宁
  /// [type]                    转链类型  好价传6   默认为5
  ///
  @override
  Future<DSResponseObject<TurnChainEntity>> turnChainForItemId(
      {String itemId,
      String platform,
      String type = '5',
      String sellerId = ''}) async {
    Map<String, dynamic> data = {
      'item_id': itemId,
      'platform': platform,
      'type': type
    };
    if (sellerId != null && sellerId.isNotEmpty) {
      data['seller_id'] = sellerId;
    }
    dynamic result = await DSDioUtil.getInstance()
        .get('turnChain.getItemUrl', queryParameters: data);
    return DSResponseObject<TurnChainEntity>.fromJson(
        result, TurnChainEntity.fromJson);
  }

  ///
  /// 好价推荐列表
  /// [keywords]              搜索关键词
  /// [excludeId]             排除id
  /// [page]                  当前页码
  /// [pagesize]              当前页显示的大小
  ///
  @override
  Future<DSResponseList<ProductItemEntity>> getSellingRecommends({
    String keywords,
    String excludeId,
    int page = 1,
    int pagesize = 10,
  }) async {
    Map<String, dynamic> data = {'page': page, 'pagesize': pagesize};
    if (keywords != null) {
      data['keywords'] = keywords;
    }
    if (excludeId != null) {
      data['exclude_id'] = excludeId;
    }
    dynamic result = await DSDioUtil.getInstance()
        .get('itemSelling.getRecommends', queryParameters: data);
    return DSResponseList<ProductItemEntity>.fromJson(
        result, ProductItemEntity.fromJson);
  }
}
